@@ -25,137 +25,189 @@ class BackupEngine {
     }
     
     public function createSiteBackup($user, $domain, $targetId) {
-        $sitePath = "/docker/users/$user/$domain";
-        
-        if (!is_dir($sitePath)) {
-            throw new Exception("Site directory not found: $sitePath");
+        try {
+            $sitePath = "/docker/users/$user/$domain";
+
+            if (!is_dir($sitePath)) {
+                return [
+                    'success' => false,
+                    'error' => "Site directory not found: $sitePath"
+                ];
+            }
+
+            $target = new BackupTarget($this->db, $targetId);
+            if (!$target->canAccess($user)) {
+                return [
+                    'success' => false,
+                    'error' => "Access denied to backup target"
+                ];
+            }
+
+            $backupName = "{$user}_{$domain}_site_" . date('Y-m-d_H-i-s');
+            $tempFile = $this->tempDir . '/' . $backupName . '.tar.gz';
+            $remotePath = "$user/sites/$domain/" . $backupName . '.tar.gz';
+
+            // Create backup history record
+            $history = new BackupHistory($this->db);
+            $result = $history->create([
+                'target_id' => $targetId,
+                'user' => $user,
+                'backup_type' => 'site',
+                'backup_name' => $backupName,
+                'backup_path' => $remotePath,
+                'status' => 'pending',
+                'metadata' => [
+                    'domain' => $domain,
+                    'source_path' => $sitePath
+                ]
+            ]);
+
+            if (!$result) {
+                return [
+                    'success' => false,
+                    'error' => "Failed to create backup record"
+                ];
+            }
+
+            // Trigger background processing
+            $this->triggerBackgroundProcessing();
+
+            return [
+                'success' => true,
+                'backup_id' => $history->getId(),
+                'backup_name' => $backupName,
+                'status' => 'pending'
+            ];
+        } catch (Exception $e) {
+            return [
+                'success' => false,
+                'error' => $e->getMessage()
+            ];
         }
-        
-        $target = new BackupTarget($this->db, $targetId);
-        if (!$target->canAccess($user)) {
-            throw new Exception("Access denied to backup target");
-        }
-        
-        $backupName = "{$user}_{$domain}_site_" . date('Y-m-d_H-i-s');
-        $tempFile = $this->tempDir . '/' . $backupName . '.tar.gz';
-        $remotePath = "$user/sites/$domain/" . $backupName . '.tar.gz';
-        
-        // Create backup history record
-        $history = new BackupHistory($this->db);
-        $result = $history->create([
-            'target_id' => $targetId,
-            'user' => $user,
-            'backup_type' => 'site',
-            'backup_name' => $backupName,
-            'backup_path' => $remotePath,
-            'status' => 'pending',
-            'metadata' => [
-                'domain' => $domain,
-                'source_path' => $sitePath
-            ]
-        ]);
-        
-        if (!$result) {
-            throw new Exception("Failed to create backup record");
-        }
-        
-        // Trigger background processing
-        $this->triggerBackgroundProcessing();
-        
-        return [
-            'success' => true,
-            'backup_id' => $history->getId(),
-            'backup_name' => $backupName,
-            'status' => 'pending'
-        ];
     }
     
     public function createUserfilesBackup($user, $targetId) {
-        $userfilesPath = "/docker/users/$user/userfiles";
-        
-        if (!is_dir($userfilesPath)) {
-            throw new Exception("Userfiles directory not found: $userfilesPath");
+        try {
+            $userfilesPath = "/docker/users/$user/userfiles";
+
+            if (!is_dir($userfilesPath)) {
+                return [
+                    'success' => false,
+                    'error' => "Userfiles directory not found: $userfilesPath"
+                ];
+            }
+
+            $target = new BackupTarget($this->db, $targetId);
+            if (!$target->canAccess($user)) {
+                return [
+                    'success' => false,
+                    'error' => "Access denied to backup target"
+                ];
+            }
+
+            $backupName = "{$user}_userfiles_" . date('Y-m-d_H-i-s');
+            $tempFile = $this->tempDir . '/' . $backupName . '.zip';
+            $remotePath = "$user/userfiles/" . $backupName . '.zip';
+
+            // Create backup history record
+            $history = new BackupHistory($this->db);
+            $result = $history->create([
+                'target_id' => $targetId,
+                'user' => $user,
+                'backup_type' => 'userfiles',
+                'backup_name' => $backupName,
+                'backup_path' => $remotePath,
+                'status' => 'pending',
+                'metadata' => [
+                    'source_path' => $userfilesPath
+                ]
+            ]);
+
+            if (!$result) {
+                return [
+                    'success' => false,
+                    'error' => "Failed to create backup record"
+                ];
+            }
+
+            // Trigger background processing
+            $this->triggerBackgroundProcessing();
+
+            return [
+                'success' => true,
+                'backup_id' => $history->getId(),
+                'backup_name' => $backupName,
+                'status' => 'pending'
+            ];
+        } catch (Exception $e) {
+            return [
+                'success' => false,
+                'error' => $e->getMessage()
+            ];
         }
-        
-        $target = new BackupTarget($this->db, $targetId);
-        if (!$target->canAccess($user)) {
-            throw new Exception("Access denied to backup target");
-        }
-        
-        $backupName = "{$user}_userfiles_" . date('Y-m-d_H-i-s');
-        $tempFile = $this->tempDir . '/' . $backupName . '.zip';
-        $remotePath = "$user/userfiles/" . $backupName . '.zip';
-        
-        // Create backup history record
-        $history = new BackupHistory($this->db);
-        $history->create([
-            'target_id' => $targetId,
-            'user' => $user,
-            'backup_type' => 'userfiles',
-            'backup_name' => $backupName,
-            'backup_path' => $remotePath,
-            'status' => 'pending',
-            'metadata' => [
-                'source_path' => $userfilesPath
-            ]
-        ]);
-        
-        // Trigger background processing
-        $this->triggerBackgroundProcessing();
-        
-        return [
-            'success' => true,
-            'backup_id' => $history->getId(),
-            'backup_name' => $backupName,
-            'status' => 'pending'
-        ];
     }
     
     public function createDatabaseBackup($user, $database, $targetId) {
-        $target = new BackupTarget($this->db, $targetId);
-        if (!$target->canAccess($user)) {
-            throw new Exception("Access denied to backup target");
+        try {
+            $target = new BackupTarget($this->db, $targetId);
+            if (!$target->canAccess($user)) {
+                return [
+                    'success' => false,
+                    'error' => "Access denied to backup target"
+                ];
+            }
+
+            // Ensure database name is properly formatted and not empty
+            if (empty($database)) {
+                return [
+                    'success' => false,
+                    'error' => "Database name cannot be empty"
+                ];
+            }
+
+            // Log database backup creation for debugging
+            error_log("Creating database backup - User: $user, Database: $database, Target: $targetId");
+
+            $backupName = "{$user}_{$database}_db_" . date('Y-m-d_H-i-s');
+            $tempFile = $this->tempDir . '/' . $backupName . '.sql.gz';
+            $remotePath = "$user/databases/" . $backupName . '.sql.gz';
+
+            // Create backup history record
+            $history = new BackupHistory($this->db);
+            $result = $history->create([
+                'target_id' => $targetId,
+                'user' => $user,
+                'backup_type' => 'database',
+                'backup_name' => $backupName,
+                'backup_path' => $remotePath,
+                'status' => 'pending',
+                'metadata' => [
+                    'database' => $database
+                ]
+            ]);
+
+            if (!$result) {
+                return [
+                    'success' => false,
+                    'error' => "Failed to create backup record"
+                ];
+            }
+
+            // Trigger background processing
+            $this->triggerBackgroundProcessing();
+
+            return [
+                'success' => true,
+                'backup_id' => $history->getId(),
+                'backup_name' => $backupName,
+                'status' => 'pending'
+            ];
+        } catch (Exception $e) {
+            return [
+                'success' => false,
+                'error' => $e->getMessage()
+            ];
         }
-        
-        // Ensure database name is properly formatted and not empty
-        if (empty($database)) {
-            throw new Exception("Database name cannot be empty");
-        }
-        
-        // Log database backup creation for debugging
-        error_log("Creating database backup - User: $user, Database: $database, Target: $targetId");
-        
-        $backupName = "{$user}_{$database}_db_" . date('Y-m-d_H-i-s');
-        $tempFile = $this->tempDir . '/' . $backupName . '.sql.gz';
-        $remotePath = "$user/databases/" . $backupName . '.sql.gz';
-        
-        // Create backup history record
-        $history = new BackupHistory($this->db);
-        $result = $history->create([
-            'target_id' => $targetId,
-            'user' => $user,
-            'backup_type' => 'database',
-            'backup_name' => $backupName,
-            'backup_path' => $remotePath,
-            'status' => 'pending',
-            'metadata' => [
-                'database' => $database
-            ]
-        ]);
-        
-        if (!$result) {
-            throw new Exception("Failed to create backup record");
-        }
-        
-        // Trigger background processing
-        $this->triggerBackgroundProcessing();
-        
-        return [
-            'success' => true,
-            'backup_id' => $history->getId(),
-            'backup_name' => $backupName,
-            'status' => 'pending'
-        ];
     }
     
     public function downloadBackup($backupId, $user) {
